pub struct SessionReaper { /* private fields */ }Expand description
Background session reaper. Runs in its own thread, periodically scanning the coordinator for expired sessions.
Implementations
Sourceimpl SessionReaper
impl SessionReaper
Sourcepub fn new(coordinator: Arc<Mutex<Coordinator>>, config: ReaperConfig) -> Self
pub fn new(coordinator: Arc<Mutex<Coordinator>>, config: ReaperConfig) -> Self
Create a new reaper for the given shared coordinator.